@@ -32,13 +32,15 @@ LICENSE = """\
 def init_extractor(args):
     category = args.category
 
-    files = [(util.path("test", "results", f"{category}.py"),
-              generate_test, False)]
+    files = []
     if args.init_module:
         files.append((util.path("gallery_dl", "extractor", f"{category}.py"),
                       generate_module, False))
         files.append((util.path("gallery_dl", "extractor", "__init__.py"),
                       insert_into_modules_list, True))
+    if args.init_test:
+        files.append((util.path("test", "results", f"{category}.py"),
+                      generate_test, False))
     if args.site_name:
         files.append((util.path("scripts", "supportedsites.py"),
                       insert_into_supportedsites, True))
@@ -89,19 +91,35 @@ def generate_module(args):
 
 def generate_extractors_basic(args):
     cat = args.category
+    ccat = cat.capitalize()
 
-    return f'''\
+    result = f'''\
 from .common import Extractor, Message
 from .. import text
 
 {build_base_pattern(args)}
 
-class {cat.capitalize()}Extractor(Extractor):
+class {ccat}Extractor(Extractor):
     """Base class for {cat} extractors"""
     category = "{cat}"
     root = "{args.root}"
 '''
 
+    for subcat in args.subcategories:
+        subcat = subcat.lower()
+        result = f'''{result}
+
+class {ccat}{subcat.capitalize()}Extractor({ccat}Extractor):
+    subcategory = "{subcat}"
+    pattern = rf"{{BASE_PATTERN}}/PATH"
+    example = "{args.root}/..."
+
+    def items(self):
+        pass
+'''
+
+    return result
+
 
 def generate_extractors_manga(args):
     cat = args.category
@@ -298,11 +316,14 @@ def parse_args(args=None):
     parser = argparse.ArgumentParser(args)
 
     parser.add_argument(
-        "-s", "--site",
+        "-s", "--subcategory",
+        dest="subcategories", metavar="SUBCaT", action="append")
+    parser.add_argument(
+        "-n", "--name",
         dest="site_name", metavar="TITLE")
     parser.add_argument(
         "-c", "--copyright",
-        dest="copyright", metavar="NAME")
+        dest="copyright", metavar="NAME", default="")
     parser.add_argument(
         "-C",
         dest="copyright", action="store_const", const="Mike Fährmann")
@@ -315,6 +336,9 @@ def parse_args(args=None):
     parser.add_argument(
         "-M", "--no-module",
         dest="init_module", action="store_false")
+    parser.add_argument(
+        "-T", "--no-test",
+        dest="init_test", action="store_false")
     parser.add_argument(
         "-t", "--type",
         dest="type", metavar="TYPE")
@@ -332,6 +356,7 @@ def parse_args(args=None):
     parser.add_argument("root", nargs="?")
 
     args = parser.parse_args()
+    args.category = args.category.lower()
 
     if root := args.root:
         if "://" in root:
