@@ -42,6 +42,7 @@ CATEGORY_MAP = {
     "cien"           : "Ci-en",
     "cohost"         : "cohost!",
     "comicvine"      : "Comic Vine",
+    "cyberfile"      : "CyberFile",
     "dankefuerslesen": "Danke fürs Lesen",
     "deviantart"     : "DeviantArt",
     "drawfriends"    : "Draw Friends",
@@ -158,6 +159,7 @@ CATEGORY_MAP = {
     "sensescans"     : "Sense-Scans",
     "sexcom"         : "Sex.com",
     "silverpic"      : "SilverPic.com",
+    "simpcity"       : "SimpCity Forums",
     "simplyhentai"   : "Simply Hentai",
     "sizebooru"      : "Size Booru",
     "slickpic"       : "SlickPic",
@@ -589,7 +591,7 @@ def subcategory_text(bc, c, sc):
         sc = f"{sc[:-1]}ies"
     elif sc.endswith("h"):
         sc = f"{sc}es"
-    elif not sc.endswith("s"):
+    elif not sc.endswith("s") and not sc.endswith("edia"):
         sc = f"{sc}s"
     return sc
 
