@@ -181,6 +181,13 @@ __tests__ = (
     "#class"    : tiktok.TiktokPostExtractor,
 },
 
+{
+    "#url"     : "https://www.tiktok.com/@veronicaperasso_1/video/7212008840433274118",
+    "#comment" : "no 'author' (#8189)",
+    "#class"   : tiktok.TiktokPostExtractor,
+    "#results" : "ytdl:https://www.tiktok.com/@veronicaperasso_1/video/7212008840433274118",
+},
+
 {
     "#url"      : "https://vm.tiktok.com/ZGdh4WUhr/",
     "#comment"  : "vm.tiktok.com link: many photos",
