@@ -772,4 +772,29 @@ The Washington Post writes, "Three weeks after the toxic train derailment in Ohi
     "#class"   : twitter.TwitterImageExtractor,
 },
 
+{
+    "#url"     : "https://x.com/tetsuoai/highlights",
+    "#class"   : twitter.TwitterHighlightsExtractor,
+},
+
+{
+    "#url"     : "https://x.com/home",
+    "#class"   : twitter.TwitterHomeExtractor,
+},
+
+{
+    "#url"     : "https://x.com/home/for_you",
+    "#class"   : twitter.TwitterHomeExtractor,
+},
+
+{
+    "#url"     : "https://x.com/home/following",
+    "#class"   : twitter.TwitterHomeExtractor,
+},
+
+{
+    "#url"     : "https://x.com/i/timeline",
+    "#class"   : twitter.TwitterHomeExtractor,
+},
+
 )
